@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2025-04-23
+# Release 2025-06-13
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.8.1
+MAKERESOLVEDEB_VERSION=1.8.2
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -430,6 +430,7 @@ process_20() {
     create_directory "${RESOLVE_BASE_DIR}"/.license
     create_directory "${RESOLVE_BASE_DIR}"/share
     create_directory "${RESOLVE_BASE_DIR}"/Fairlight
+    create_directory "${RESOLVE_BASE_DIR}"/Extras
 
     # Copy objects
     copy_object "${UNPACK_DIR}"/bin "${RESOLVE_BASE_DIR}"
@@ -480,6 +481,7 @@ chmod -R a+rw /opt/resolve/LUT
 chmod -R a+rw /opt/resolve/.license
 chmod -R a+rw /opt/resolve/Fairlight
 chmod -R a+rw /var/BlackmagicDesign/"DaVinci Resolve"
+chmod -R a+rw /opt/resolve/Extras
 EOF
 }
 
